## quill ⠶ fold

_[mani]fold_

- `qu`⠶`fold`: Manage `*.spin.systems` subdomains
  - Read name list in `spin`⠶`ss`⠶`manifest.mmd`
  - Check for directories with these names under `spin`⠶`ss`
  - Read domain metadata from `remote.yml`
  - Write `spin`⠶`ss`⠶`README.md` reflecting the configuration

- `wire` is a build engine aimed to do 'real-time' things ('to the wire', e.g. live transcripts)
- `cut` is a templating engine built on `staticjinja` for ready-made ('cut-out') web content
  production. It doesn't use the MMD format.
